from setuptools import setup

setup(
    name='apache-beam-with-aws',
    version="1.0.0",
    description='apache-beam-with-aws - listed by Cycode to prevent confusion',
    long_description="apache-beam-with-aws",
    long_description_content_type='text/markdown',
)
